Tensors
=======

.. toctree::
   :maxdepth: 1

   sage/tensor/modules/reflexive_module

   sage/tensor/modules/tensor_free_module

   sage/tensor/modules/tensor_free_submodule

   sage/tensor/modules/free_module_tensor

   sage/tensor/modules/tensor_with_indices

   sage/tensor/modules/tensor_free_submodule_basis
